==> FlightGear-0.7.2.tar.gz: FlightGear-0.7.2/src/FDM/External.cxx <==
// External.cxx -- interface to the "External"-ly driven flight model
//
// Written by Curtis Olson, started November 1999.
//
// Copyright (C) 1999  Curtis L. Olson  - curt@flightgear.org
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// $Id: External.cxx,v 1.1 1999/11/19 01:12:46 curt Exp $


#include "External.hxx"


// Initialize the External flight model, dt is the time increment
// for each subsequent iteration through the EOM
int FGExternal::init( double dt ) {
    // cout << "FGExternal::init()" << endl;

    // set valid time for this record
    stamp_time();

    return 1;
}


// Run an iteration of the EOM.  This is essentially a NOP here
// because these values are getting filled in elsewhere based on
// external input.
int FGExternal::update( int multiloop ) {
    // cout << "FGExternal::update()" << endl;

    // double time_step = (1.0 / current_options.get_model_hz()) * multiloop;


    return 1;
}

==> FlightGear-0.7.6.tar.gz: FlightGear-0.7.6/src/FDM/External.cxx <==
// External.cxx -- interface to the "External"-ly driven flight model
//
// Written by Curtis Olson, started November 1999.
//
// Copyright (C) 1999  Curtis L. Olson  - curt@flightgear.org
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License as
// published by the Free Software Foundation; either version 2 of the
// License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
//
// $Id: External.cxx,v 1.3 2000/10/19 19:24:46 curt Exp $


#include "External.hxx"


// Initialize the External flight model, dt is the time increment
// for each subsequent iteration through the EOM
bool FGExternal::init( double dt ) {
    // cout << "FGExternal::init()" << endl;

    // set valid time for this record
    stamp_time();

    return true;
}


// Run an iteration of the EOM.  This is essentially a NOP here
// because these values are getting filled in elsewhere based on
// external input.
bool FGExternal::update( int multiloop ) {
    // cout << "FGExternal::update()" << endl;

    // double time_step = (1.0 / globals->get_options()->get_model_hz())
    //                     * multiloop;


    return true;
}
